# Generated by Django 4.1.6 on 2023-02-21 10:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_idom", "0002_rename_created_at_componentparams_last_accessed"),
    ]

    operations = [
        migrations.CreateModel(
            name="ComponentSession",
            fields=[
                (
                    "uuid",
                    models.UUIDField(
                        editable=False, primary_key=True, serialize=False, unique=True
                    ),
                ),
                ("params", models.BinaryField()),
                ("last_accessed", models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.DeleteModel(
            name="ComponentParams",
        ),
    ]
